@@ -48,18 +48,16 @@ __keywords__ = "plotting"
 
 # Common setup for matplotlib
 params = {'backend': 'pdf',
-          'savefig.dpi': 300, # save figures to 300 dpi
+          'savefig.dpi': 300,
           'axes.labelsize': 10,
-          'text.fontsize': 10,
+          'text.fontsize': 8,
           'legend.fontsize': 10,
+          'figure.figsize': (cm2inch(8.8), cm2inch(8.8) * 6 / 8),
           'xtick.labelsize': 10,
           'ytick.major.pad': 6,
           'xtick.major.pad': 6,
           'ytick.labelsize': 10,
-          'text.usetex': True,
-          'font.family':'sans-serif',
-          # free font similar to Helvetica
-          'font.sans-serif':'FreeSans'}
+          'font.family': 'sans-serif'}
 
 
 def specshow(image, **kwargs):
@@ -72,9 +70,19 @@ def specshow(image, **kwargs):
 
 def cm2inch(cm):
     """Centimeters to inches"""
-    return 0.393701 * cm 
+    return 0.393701 * cm
+
 
 def inch2cm(inches):
     """Inches to centimeters"""
-    return inches / 0.393701 
+    return inches / 0.393701
 
+
+def figsize(width):
+    """Return figsize mpl parameter from a width in cm"""
+    return (cm2inch(width), cm2inch(width) * 6 / 8)
+
+
+def savefig(path):
+    """mpl savefig with common options"""
+    plt.savefig(path, bbox_inches='tight', pad_inches=0)
