@@ -189,8 +189,8 @@ def uirfftn(inarray, dim=None):
     else:
         outarray = np.fft.irfftn(inarray, axes=range(-dim, 0))
 
-    return outarray * np.sqrt(np.prod(inarray.shape[-dim:-1] *
-                                      (inarray.shape[-1] - 1) * 2))
+    return outarray * np.sqrt(np.prod(inarray.shape[-dim:-1]) *
+                              (inarray.shape[-1] - 1) * 2)
 
 
 def ufft2(inarray):
